-------------------------------------------------------------------
-- System Generator version 10.1.00 VHDL source file.
--
-- Copyright(C) 2007 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the user's
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2007 Xilinx, Inc.  All rights
-- reserved.
-------------------------------------------------------------------
library IEEE;
use IEEE.std_logic_1164.all;

entity plbaddrpref is
    generic (
        C_BASEADDR : std_logic_vector(31 downto 0) := X"80000000";
        C_HIGHADDR : std_logic_vector(31 downto 0) := X"8000FFFF";
        C_SPLB_DWIDTH         : integer range 32 to 128   := 32;
        C_SPLB_NATIVE_DWIDTH  : integer range 32 to 32    := 32
    );
    port (
        addrpref           : out std_logic_vector(17-1 downto 0);
        sl_rddbus          : out std_logic_vector(0 to C_SPLB_DWIDTH-1);
        plb_wrdbus         : in  std_logic_vector(0 to C_SPLB_DWIDTH-1);
        sgsl_rddbus        : in  std_logic_vector(0 to C_SPLB_NATIVE_DWIDTH-1);
        sgplb_wrdbus       : out std_logic_vector(0 to C_SPLB_NATIVE_DWIDTH-1)
    );
end plbaddrpref;

architecture behavior of plbaddrpref is

signal sl_rddbus_i            : std_logic_vector(0 to C_SPLB_DWIDTH-1);

begin
    addrpref <= C_BASEADDR(32-1 downto 15);

-------------------------------------------------------------------------------
-- Mux/Steer data/be's correctly for connect 32-bit slave to 128-bit plb
-------------------------------------------------------------------------------
GEN_128_TO_32_SLAVE : if C_SPLB_NATIVE_DWIDTH = 32 and C_SPLB_DWIDTH = 128 generate
begin
    -----------------------------------------------------------------------
    -- Map lower rd data to each quarter of the plb slave read bus
    -----------------------------------------------------------------------
    sl_rddbus_i(0 to 31)      <=  sgsl_rddbus(0 to C_SPLB_NATIVE_DWIDTH-1);
    sl_rddbus_i(32 to 63)     <=  sgsl_rddbus(0 to C_SPLB_NATIVE_DWIDTH-1);
    sl_rddbus_i(64 to 95)     <=  sgsl_rddbus(0 to C_SPLB_NATIVE_DWIDTH-1);
    sl_rddbus_i(96 to 127)    <=  sgsl_rddbus(0 to C_SPLB_NATIVE_DWIDTH-1);
end generate GEN_128_TO_32_SLAVE;

-------------------------------------------------------------------------------
-- Mux/Steer data/be's correctly for connect 32-bit slave to 64-bit plb
-------------------------------------------------------------------------------
GEN_64_TO_32_SLAVE : if C_SPLB_NATIVE_DWIDTH = 32 and C_SPLB_DWIDTH = 64 generate
begin
    ---------------------------------------------------------------------------        
    -- Map lower rd data to upper and lower halves of plb slave read bus
    ---------------------------------------------------------------------------        
    sl_rddbus_i(0 to 31)      <=  sgsl_rddbus(0 to C_SPLB_NATIVE_DWIDTH-1);
    sl_rddbus_i(32 to 63)     <=  sgsl_rddbus(0 to C_SPLB_NATIVE_DWIDTH-1);
end generate GEN_64_TO_32_SLAVE;

-------------------------------------------------------------------------------
-- IPIF DWidth = PLB DWidth
-- If IPIF Slave Data width is equal to the PLB Bus Data Width
-- Then BE and Read Data Bus map directly to eachother.
-------------------------------------------------------------------------------
GEN_FOR_EQUAL_SLAVE : if C_SPLB_NATIVE_DWIDTH = C_SPLB_DWIDTH generate
    sl_rddbus_i    <= sgsl_rddbus;
end generate GEN_FOR_EQUAL_SLAVE;

    sl_rddbus       <= sl_rddbus_i;
    sgplb_wrdbus    <= plb_wrdbus(0 to C_SPLB_NATIVE_DWIDTH-1);

end behavior;
library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;

entity ofdm_txrx_supermimo_plbw is
  generic (
    C_BASEADDR: std_logic_vector(31 downto 0) := X"80000000";
    C_HIGHADDR: std_logic_vector(31 downto 0) := X"80000FFF";
    C_SPLB_DWIDTH: integer range 32 to 128 := 32;
    C_SPLB_NATIVE_DWIDTH: integer range 32 to 32 := 32;
    C_SPLB_AWIDTH: integer := 0;
    C_SPLB_P2P: integer := 0;
    C_SPLB_MID_WIDTH: integer := 0;
    C_SPLB_NUM_MASTERS: integer := 0;
    C_SPLB_SUPPORT_BURSTS: integer := 0;
    C_MEMMAP_RX_BER_ERRORS: integer := 0;
    C_MEMMAP_RX_BER_ERRORS_N_BITS: integer := 0;
    C_MEMMAP_RX_BER_ERRORS_BIN_PT: integer := 0;
    C_MEMMAP_RX_BER_TOTALBITS: integer := 0;
    C_MEMMAP_RX_BER_TOTALBITS_N_BITS: integer := 0;
    C_MEMMAP_RX_BER_TOTALBITS_BIN_PT: integer := 0;
    C_MEMMAP_RX_CONTROLBITS_R: integer := 0;
    C_MEMMAP_RX_CONTROLBITS_R_N_BITS: integer := 0;
    C_MEMMAP_RX_CONTROLBITS_R_BIN_PT: integer := 0;
    C_MEMMAP_RX_GAINS: integer := 0;
    C_MEMMAP_RX_GAINS_N_BITS: integer := 0;
    C_MEMMAP_RX_GAINS_BIN_PT: integer := 0;
    C_MEMMAP_RX_OFDM_SYMBOLCOUNTS_R: integer := 0;
    C_MEMMAP_RX_OFDM_SYMBOLCOUNTS_R_N_BITS: integer := 0;
    C_MEMMAP_RX_OFDM_SYMBOLCOUNTS_R_BIN_PT: integer := 0;
    C_MEMMAP_RX_PKTDET_DELAY_R: integer := 0;
    C_MEMMAP_RX_PKTDET_DELAY_R_N_BITS: integer := 0;
    C_MEMMAP_RX_PKTDET_DELAY_R_BIN_PT: integer := 0;
    C_MEMMAP_RX_PKTDET_LONGCORR_PARAMS_R: integer := 0;
    C_MEMMAP_RX_PKTDET_LONGCORR_PARAMS_R_N_BITS: integer := 0;
    C_MEMMAP_RX_PKTDET_LONGCORR_PARAMS_R_BIN_PT: integer := 0;
    C_MEMMAP_RX_PKTBYTENUMS_R: integer := 0;
    C_MEMMAP_RX_PKTBYTENUMS_R_N_BITS: integer := 0;
    C_MEMMAP_RX_PKTBYTENUMS_R_BIN_PT: integer := 0;
    C_MEMMAP_RX_PKTDONE_INTERRUPTSTATUS: integer := 0;
    C_MEMMAP_RX_PKTDONE_INTERRUPTSTATUS_N_BITS: integer := 0;
    C_MEMMAP_RX_PKTDONE_INTERRUPTSTATUS_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION0_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION0_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION0_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION1_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION1_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION1_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION2_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION2_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION2_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION3_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION3_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION3_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION4_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION4_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION4_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION5_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION5_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION5_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH0_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH0_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH0_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH1_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH1_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH1_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH2_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH2_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH2_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH3_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH3_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH3_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH4_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH4_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH4_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH5_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH5_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH5_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH6_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH6_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH6_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH7_R: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH7_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH7_R_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_INTERRUPT_PKTBUF_CTRL_R: integer := 0;
    C_MEMMAP_TXRX_INTERRUPT_PKTBUF_CTRL_R_N_BITS: integer := 0;
    C_MEMMAP_TXRX_INTERRUPT_PKTBUF_CTRL_R_BIN_PT: integer := 0;
    C_MEMMAP_TX_CONTROLBITS_R: integer := 0;
    C_MEMMAP_TX_CONTROLBITS_R_N_BITS: integer := 0;
    C_MEMMAP_TX_CONTROLBITS_R_BIN_PT: integer := 0;
    C_MEMMAP_TX_OFDM_SYMCOUNTS_R: integer := 0;
    C_MEMMAP_TX_OFDM_SYMCOUNTS_R_N_BITS: integer := 0;
    C_MEMMAP_TX_OFDM_SYMCOUNTS_R_BIN_PT: integer := 0;
    C_MEMMAP_TX_PKTRUNNING: integer := 0;
    C_MEMMAP_TX_PKTRUNNING_N_BITS: integer := 0;
    C_MEMMAP_TX_PKTRUNNING_BIN_PT: integer := 0;
    C_MEMMAP_TX_START_RESET_CONTROL_R: integer := 0;
    C_MEMMAP_TX_START_RESET_CONTROL_R_N_BITS: integer := 0;
    C_MEMMAP_TX_START_RESET_CONTROL_R_BIN_PT: integer := 0;
    C_MEMMAP_MIDPACKETRSSI: integer := 0;
    C_MEMMAP_MIDPACKETRSSI_N_BITS: integer := 0;
    C_MEMMAP_MIDPACKETRSSI_BIN_PT: integer := 0;
    C_MEMMAP_PKTDET_CONTROLBITS_R: integer := 0;
    C_MEMMAP_PKTDET_CONTROLBITS_R_N_BITS: integer := 0;
    C_MEMMAP_PKTDET_CONTROLBITS_R_BIN_PT: integer := 0;
    C_MEMMAP_PKTDET_DURATIONS_R: integer := 0;
    C_MEMMAP_PKTDET_DURATIONS_R_N_BITS: integer := 0;
    C_MEMMAP_PKTDET_DURATIONS_R_BIN_PT: integer := 0;
    C_MEMMAP_PKTDET_STATUS: integer := 0;
    C_MEMMAP_PKTDET_STATUS_N_BITS: integer := 0;
    C_MEMMAP_PKTDET_STATUS_BIN_PT: integer := 0;
    C_MEMMAP_PKTDET_THRESHOLDS_R: integer := 0;
    C_MEMMAP_PKTDET_THRESHOLDS_R_N_BITS: integer := 0;
    C_MEMMAP_PKTDET_THRESHOLDS_R_BIN_PT: integer := 0;
    C_MEMMAP_RX_AF_TXSCALING_W: integer := 0;
    C_MEMMAP_RX_AF_TXSCALING_W_N_BITS: integer := 0;
    C_MEMMAP_RX_AF_TXSCALING_W_BIN_PT: integer := 0;
    C_MEMMAP_RX_CONSTELLATION_SCALING_W: integer := 0;
    C_MEMMAP_RX_CONSTELLATION_SCALING_W_N_BITS: integer := 0;
    C_MEMMAP_RX_CONSTELLATION_SCALING_W_BIN_PT: integer := 0;
    C_MEMMAP_RX_CONTROLBITS_W: integer := 0;
    C_MEMMAP_RX_CONTROLBITS_W_N_BITS: integer := 0;
    C_MEMMAP_RX_CONTROLBITS_W_BIN_PT: integer := 0;
    C_MEMMAP_RX_FREQOFFFILT_B_KI_W: integer := 0;
    C_MEMMAP_RX_FREQOFFFILT_B_KI_W_N_BITS: integer := 0;
    C_MEMMAP_RX_FREQOFFFILT_B_KI_W_BIN_PT: integer := 0;
    C_MEMMAP_RX_FREQOFFFILT_B_KP_W: integer := 0;
    C_MEMMAP_RX_FREQOFFFILT_B_KP_W_N_BITS: integer := 0;
    C_MEMMAP_RX_FREQOFFFILT_B_KP_W_BIN_PT: integer := 0;
    C_MEMMAP_RX_MINREQPILOTCHANMAG_W: integer := 0;
    C_MEMMAP_RX_MINREQPILOTCHANMAG_W_N_BITS: integer := 0;
    C_MEMMAP_RX_MINREQPILOTCHANMAG_W_BIN_PT: integer := 0;
    C_MEMMAP_RX_OFDM_SYMBOLCOUNTS_W: integer := 0;
    C_MEMMAP_RX_OFDM_SYMBOLCOUNTS_W_N_BITS: integer := 0;
    C_MEMMAP_RX_OFDM_SYMBOLCOUNTS_W_BIN_PT: integer := 0;
    C_MEMMAP_RX_PHASENOISETRACK_K_W: integer := 0;
    C_MEMMAP_RX_PHASENOISETRACK_K_W_N_BITS: integer := 0;
    C_MEMMAP_RX_PHASENOISETRACK_K_W_BIN_PT: integer := 0;
    C_MEMMAP_RX_PKTDET_DELAY_W: integer := 0;
    C_MEMMAP_RX_PKTDET_DELAY_W_N_BITS: integer := 0;
    C_MEMMAP_RX_PKTDET_DELAY_W_BIN_PT: integer := 0;
    C_MEMMAP_RX_PKTDET_LONGCORR_PARAMS_W: integer := 0;
    C_MEMMAP_RX_PKTDET_LONGCORR_PARAMS_W_N_BITS: integer := 0;
    C_MEMMAP_RX_PKTDET_LONGCORR_PARAMS_W_BIN_PT: integer := 0;
    C_MEMMAP_RX_PRECFO_OPTIONS_W: integer := 0;
    C_MEMMAP_RX_PRECFO_OPTIONS_W_N_BITS: integer := 0;
    C_MEMMAP_RX_PRECFO_OPTIONS_W_BIN_PT: integer := 0;
    C_MEMMAP_RX_PKTBYTENUMS_W: integer := 0;
    C_MEMMAP_RX_PKTBYTENUMS_W_N_BITS: integer := 0;
    C_MEMMAP_RX_PKTBYTENUMS_W_BIN_PT: integer := 0;
    C_MEMMAP_RX_PKTDET_TRESHOLDS_W: integer := 0;
    C_MEMMAP_RX_PKTDET_TRESHOLDS_W_N_BITS: integer := 0;
    C_MEMMAP_RX_PKTDET_TRESHOLDS_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION0_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION0_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION0_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION1_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION1_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION1_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION2_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION2_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION2_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION3_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION3_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION3_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION4_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION4_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION4_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION5_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION5_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_ACTION5_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH0_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH0_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH0_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH1_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH1_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH1_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH2_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH2_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH2_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH3_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH3_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH3_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH4_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH4_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH4_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH5_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH5_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH5_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH6_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH6_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH6_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH7_W: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH7_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_AUTOREPLY_MATCH7_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_FFT_SCALING_W: integer := 0;
    C_MEMMAP_TXRX_FFT_SCALING_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_FFT_SCALING_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_INTERRUPT_PKTBUF_CTRL_W: integer := 0;
    C_MEMMAP_TXRX_INTERRUPT_PKTBUF_CTRL_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_INTERRUPT_PKTBUF_CTRL_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_PILOTS_INDEX_W: integer := 0;
    C_MEMMAP_TXRX_PILOTS_INDEX_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_PILOTS_INDEX_W_BIN_PT: integer := 0;
    C_MEMMAP_TXRX_PILOTS_VALUES_W: integer := 0;
    C_MEMMAP_TXRX_PILOTS_VALUES_W_N_BITS: integer := 0;
    C_MEMMAP_TXRX_PILOTS_VALUES_W_BIN_PT: integer := 0;
    C_MEMMAP_TX_CONTROLBITS_W: integer := 0;
    C_MEMMAP_TX_CONTROLBITS_W_N_BITS: integer := 0;
    C_MEMMAP_TX_CONTROLBITS_W_BIN_PT: integer := 0;
    C_MEMMAP_TX_OFDM_SYMCOUNTS_W: integer := 0;
    C_MEMMAP_TX_OFDM_SYMCOUNTS_W_N_BITS: integer := 0;
    C_MEMMAP_TX_OFDM_SYMCOUNTS_W_BIN_PT: integer := 0;
    C_MEMMAP_TX_PREAMBLEMASKING_W: integer := 0;
    C_MEMMAP_TX_PREAMBLEMASKING_W_N_BITS: integer := 0;
    C_MEMMAP_TX_PREAMBLEMASKING_W_BIN_PT: integer := 0;
    C_MEMMAP_TX_SCALING_W: integer := 0;
    C_MEMMAP_TX_SCALING_W_N_BITS: integer := 0;
    C_MEMMAP_TX_SCALING_W_BIN_PT: integer := 0;
    C_MEMMAP_TX_START_RESET_CONTROL_W: integer := 0;
    C_MEMMAP_TX_START_RESET_CONTROL_W_N_BITS: integer := 0;
    C_MEMMAP_TX_START_RESET_CONTROL_W_BIN_PT: integer := 0;
    C_MEMMAP_PKTDET_CONTROLBITS_W: integer := 0;
    C_MEMMAP_PKTDET_CONTROLBITS_W_N_BITS: integer := 0;
    C_MEMMAP_PKTDET_CONTROLBITS_W_BIN_PT: integer := 0;
    C_MEMMAP_PKTDET_DURATIONS_W: integer := 0;
    C_MEMMAP_PKTDET_DURATIONS_W_N_BITS: integer := 0;
    C_MEMMAP_PKTDET_DURATIONS_W_BIN_PT: integer := 0;
    C_MEMMAP_PKTDET_THRESHOLDS_W: integer := 0;
    C_MEMMAP_PKTDET_THRESHOLDS_W_N_BITS: integer := 0;
    C_MEMMAP_PKTDET_THRESHOLDS_W_BIN_PT: integer := 0;
    C_MEMMAP_CHANNELESTIMATES: integer := 0;
    C_MEMMAP_CHANNELESTIMATES_N_BITS: integer := 0;
    C_MEMMAP_CHANNELESTIMATES_BIN_PT: integer := 0;
    C_MEMMAP_CHANNELESTIMATES_DEPTH: integer := 0;
    C_MEMMAP_RXMODULATION: integer := 0;
    C_MEMMAP_RXMODULATION_N_BITS: integer := 0;
    C_MEMMAP_RXMODULATION_BIN_PT: integer := 0;
    C_MEMMAP_RXMODULATION_DEPTH: integer := 0;
    C_MEMMAP_TXHEADERTRANSLATE: integer := 0;
    C_MEMMAP_TXHEADERTRANSLATE_N_BITS: integer := 0;
    C_MEMMAP_TXHEADERTRANSLATE_BIN_PT: integer := 0;
    C_MEMMAP_TXHEADERTRANSLATE_DEPTH: integer := 0;
    C_MEMMAP_TXMODULATION: integer := 0;
    C_MEMMAP_TXMODULATION_N_BITS: integer := 0;
    C_MEMMAP_TXMODULATION_BIN_PT: integer := 0;
    C_MEMMAP_TXMODULATION_DEPTH: integer := 0
  );
  port (
    bram_datain: in std_logic_vector(0 to 63); 
    ce: in std_logic; 
    debug_chipscopetrig1: in std_logic; 
    ext_txen: in std_logic; 
    plb_abus: in std_logic_vector(0 to 31); 
    plb_pavalid: in std_logic; 
    plb_rnw: in std_logic; 
    plb_wrdbus: in std_logic_vector(0 to C_SPLB_DWIDTH-1); 
    rssi_anta: in std_logic_vector(0 to 9); 
    rssi_antb: in std_logic_vector(0 to 9); 
    rx_anta_adci: in std_logic_vector(0 to 13); 
    rx_anta_adcq: in std_logic_vector(0 to 13); 
    rx_anta_agc_done: in std_logic; 
    rx_anta_gainbb: in std_logic_vector(0 to 4); 
    rx_anta_gainrf: in std_logic_vector(0 to 1); 
    rx_antb_adci: in std_logic_vector(0 to 13); 
    rx_antb_adcq: in std_logic_vector(0 to 13); 
    rx_antb_agc_done: in std_logic; 
    rx_antb_gainbb: in std_logic_vector(0 to 4); 
    rx_antb_gainrf: in std_logic_vector(0 to 1); 
    rx_reset: in std_logic; 
    shared_memory_data_out: in std_logic_vector(0 to 31); 
    splb_clk: in std_logic; 
    splb_rst: in std_logic; 
    tx_reset: in std_logic; 
    tx_starttransmit: in std_logic; 
    bram_addr: out std_logic_vector(0 to 31); 
    bram_dout: out std_logic_vector(0 to 63); 
    bram_reset: out std_logic; 
    bram_wen: out std_logic_vector(0 to 7); 
    idlefordifs: out std_logic; 
    pktdetect: out std_logic; 
    radio_rxen: out std_logic; 
    radio_txen: out std_logic; 
    rssi_clk_out: out std_logic; 
    rx_debug_antsel: out std_logic; 
    rx_debug_eq_i: out std_logic_vector(0 to 13); 
    rx_debug_eq_q: out std_logic_vector(0 to 13); 
    rx_debug_evm: out std_logic_vector(0 to 13); 
    rx_debug_payload: out std_logic; 
    rx_debug_phasecorrect: out std_logic_vector(0 to 13); 
    rx_debug_phaseerror: out std_logic_vector(0 to 13); 
    rx_debug_pktdone: out std_logic; 
    rx_int_badheader: out std_logic; 
    rx_int_badpkt: out std_logic; 
    rx_int_goodheader: out std_logic; 
    rx_int_goodpkt: out std_logic; 
    rx_pktdetreset: out std_logic; 
    shared_memory_addr: out std_logic_vector(0 to 7); 
    shared_memory_ce: out std_logic; 
    shared_memory_clk: out std_logic; 
    shared_memory_data_in: out std_logic_vector(0 to 31); 
    shared_memory_we: out std_logic_vector(0 downto 0); 
    sl_addrack: out std_logic; 
    sl_rdcomp: out std_logic; 
    sl_rddack: out std_logic; 
    sl_rddbus: out std_logic_vector(0 to C_SPLB_DWIDTH-1); 
    sl_wait: out std_logic; 
    sl_wrcomp: out std_logic; 
    sl_wrdack: out std_logic; 
    tx_anta_dac_i: out std_logic_vector(0 to 15); 
    tx_anta_dac_q: out std_logic_vector(0 to 15); 
    tx_antb_dac_i: out std_logic_vector(0 to 15); 
    tx_antb_dac_q: out std_logic_vector(0 to 15); 
    tx_debug_pktrunning: out std_logic; 
    tx_pktdone: out std_logic
  );
end ofdm_txrx_supermimo_plbw;

architecture structural of ofdm_txrx_supermimo_plbw is
  signal bram_addr_x0: std_logic_vector(31 downto 0);
  signal bram_datain_x0: std_logic_vector(63 downto 0);
  signal bram_dout_x0: std_logic_vector(63 downto 0);
  signal bram_reset_x0: std_logic;
  signal bram_wen_x0: std_logic_vector(7 downto 0);
  signal ce_x0: std_logic;
  signal clk: std_logic;
  signal debug_chipscopetrig1_x0: std_logic;
  signal ext_txen_x0: std_logic;
  signal idlefordifs_x0: std_logic;
  signal pktdetect_x0: std_logic;
  signal plb_abus_x0: std_logic_vector(31 downto 0);
  signal plb_pavalid_x0: std_logic;
  signal plb_rnw_x0: std_logic;
  signal plbaddrpref_addrpref_net: std_logic_vector(16 downto 0);
  signal plbaddrpref_plb_wrdbus_net: std_logic_vector(C_SPLB_DWIDTH-1 downto 0);
  signal plbaddrpref_sgplb_wrdbus_net: std_logic_vector(31 downto 0);
  signal plbaddrpref_sgsl_rddbus_net: std_logic_vector(31 downto 0);
  signal plbaddrpref_sl_rddbus_net: std_logic_vector(C_SPLB_DWIDTH-1 downto 0);
  signal radio_rxen_x0: std_logic;
  signal radio_txen_x0: std_logic;
  signal rssi_anta_x0: std_logic_vector(9 downto 0);
  signal rssi_antb_x0: std_logic_vector(9 downto 0);
  signal rssi_clk_out_x0: std_logic;
  signal rx_anta_adci_x0: std_logic_vector(13 downto 0);
  signal rx_anta_adcq_x0: std_logic_vector(13 downto 0);
  signal rx_anta_agc_done_x0: std_logic;
  signal rx_anta_gainbb_x0: std_logic_vector(4 downto 0);
  signal rx_anta_gainrf_x0: std_logic_vector(1 downto 0);
  signal rx_antb_adci_x0: std_logic_vector(13 downto 0);
  signal rx_antb_adcq_x0: std_logic_vector(13 downto 0);
  signal rx_antb_agc_done_x0: std_logic;
  signal rx_antb_gainbb_x0: std_logic_vector(4 downto 0);
  signal rx_antb_gainrf_x0: std_logic_vector(1 downto 0);
  signal rx_debug_antsel_x0: std_logic;
  signal rx_debug_eq_i_x0: std_logic_vector(13 downto 0);
  signal rx_debug_eq_q_x0: std_logic_vector(13 downto 0);
  signal rx_debug_evm_x0: std_logic_vector(13 downto 0);
  signal rx_debug_payload_x0: std_logic;
  signal rx_debug_phasecorrect_x0: std_logic_vector(13 downto 0);
  signal rx_debug_phaseerror_x0: std_logic_vector(13 downto 0);
  signal rx_debug_pktdone_x0: std_logic;
  signal rx_int_badheader_x0: std_logic;
  signal rx_int_badpkt_x0: std_logic;
  signal rx_int_goodheader_x0: std_logic;
  signal rx_int_goodpkt_x0: std_logic;
  signal rx_pktdetreset_x0: std_logic;
  signal rx_reset_x0: std_logic;
  signal shared_memory_addr_x0: std_logic_vector(7 downto 0);
  signal shared_memory_ce_x0: std_logic;
  signal shared_memory_clk_x0: std_logic;
  signal shared_memory_data_in_x0: std_logic_vector(31 downto 0);
  signal shared_memory_data_out_x0: std_logic_vector(31 downto 0);
  signal shared_memory_we_x0: std_logic_vector(0 downto 0);
  signal sl_addrack_x0: std_logic;
  signal sl_rdcomp_x0: std_logic;
  signal sl_rddack_x0: std_logic;
  signal sl_wait_x0: std_logic;
  signal sl_wrcomp_x0: std_logic;
  signal sl_wrdack_x0: std_logic;
  signal splb_rst_x0: std_logic;
  signal tx_anta_dac_i_x0: std_logic_vector(15 downto 0);
  signal tx_anta_dac_q_x0: std_logic_vector(15 downto 0);
  signal tx_antb_dac_i_x0: std_logic_vector(15 downto 0);
  signal tx_antb_dac_q_x0: std_logic_vector(15 downto 0);
  signal tx_debug_pktrunning_x0: std_logic;
  signal tx_pktdone_x0: std_logic;
  signal tx_reset_x0: std_logic;
  signal tx_starttransmit_x0: std_logic;

begin
  bram_datain_x0 <= bram_datain;
  ce_x0 <= ce;
  debug_chipscopetrig1_x0 <= debug_chipscopetrig1;
  ext_txen_x0 <= ext_txen;
  plb_abus_x0 <= plb_abus;
  plb_pavalid_x0 <= plb_pavalid;
  plb_rnw_x0 <= plb_rnw;
  plbaddrpref_plb_wrdbus_net <= plb_wrdbus;
  rssi_anta_x0 <= rssi_anta;
  rssi_antb_x0 <= rssi_antb;
  rx_anta_adci_x0 <= rx_anta_adci;
  rx_anta_adcq_x0 <= rx_anta_adcq;
  rx_anta_agc_done_x0 <= rx_anta_agc_done;
  rx_anta_gainbb_x0 <= rx_anta_gainbb;
  rx_anta_gainrf_x0 <= rx_anta_gainrf;
  rx_antb_adci_x0 <= rx_antb_adci;
  rx_antb_adcq_x0 <= rx_antb_adcq;
  rx_antb_agc_done_x0 <= rx_antb_agc_done;
  rx_antb_gainbb_x0 <= rx_antb_gainbb;
  rx_antb_gainrf_x0 <= rx_antb_gainrf;
  rx_reset_x0 <= rx_reset;
  shared_memory_data_out_x0 <= shared_memory_data_out;
  clk <= splb_clk;
  splb_rst_x0 <= splb_rst;
  tx_reset_x0 <= tx_reset;
  tx_starttransmit_x0 <= tx_starttransmit;
  bram_addr <= bram_addr_x0;
  bram_dout <= bram_dout_x0;
  bram_reset <= bram_reset_x0;
  bram_wen <= bram_wen_x0;
  idlefordifs <= idlefordifs_x0;
  pktdetect <= pktdetect_x0;
  radio_rxen <= radio_rxen_x0;
  radio_txen <= radio_txen_x0;
  rssi_clk_out <= rssi_clk_out_x0;
  rx_debug_antsel <= rx_debug_antsel_x0;
  rx_debug_eq_i <= rx_debug_eq_i_x0;
  rx_debug_eq_q <= rx_debug_eq_q_x0;
  rx_debug_evm <= rx_debug_evm_x0;
  rx_debug_payload <= rx_debug_payload_x0;
  rx_debug_phasecorrect <= rx_debug_phasecorrect_x0;
  rx_debug_phaseerror <= rx_debug_phaseerror_x0;
  rx_debug_pktdone <= rx_debug_pktdone_x0;
  rx_int_badheader <= rx_int_badheader_x0;
  rx_int_badpkt <= rx_int_badpkt_x0;
  rx_int_goodheader <= rx_int_goodheader_x0;
  rx_int_goodpkt <= rx_int_goodpkt_x0;
  rx_pktdetreset <= rx_pktdetreset_x0;
  shared_memory_addr <= shared_memory_addr_x0;
  shared_memory_ce <= shared_memory_ce_x0;
  shared_memory_clk <= shared_memory_clk_x0;
  shared_memory_data_in <= shared_memory_data_in_x0;
  shared_memory_we <= shared_memory_we_x0;
  sl_addrack <= sl_addrack_x0;
  sl_rdcomp <= sl_rdcomp_x0;
  sl_rddack <= sl_rddack_x0;
  sl_rddbus <= plbaddrpref_sl_rddbus_net;
  sl_wait <= sl_wait_x0;
  sl_wrcomp <= sl_wrcomp_x0;
  sl_wrdack <= sl_wrdack_x0;
  tx_anta_dac_i <= tx_anta_dac_i_x0;
  tx_anta_dac_q <= tx_anta_dac_q_x0;
  tx_antb_dac_i <= tx_antb_dac_i_x0;
  tx_antb_dac_q <= tx_antb_dac_q_x0;
  tx_debug_pktrunning <= tx_debug_pktrunning_x0;
  tx_pktdone <= tx_pktdone_x0;

  plbaddrpref_x0: entity work.plbaddrpref
    generic map (
      C_BASEADDR => C_BASEADDR,
      C_HIGHADDR => C_HIGHADDR,
      C_SPLB_DWIDTH => C_SPLB_DWIDTH,
      C_SPLB_NATIVE_DWIDTH => C_SPLB_NATIVE_DWIDTH
    )
    port map (
      plb_wrdbus => plbaddrpref_plb_wrdbus_net,
      sgsl_rddbus => plbaddrpref_sgsl_rddbus_net,
      addrpref => plbaddrpref_addrpref_net,
      sgplb_wrdbus => plbaddrpref_sgplb_wrdbus_net,
      sl_rddbus => plbaddrpref_sl_rddbus_net
    );

  sysgen_dut: entity work.ofdm_txrx_supermimo_cw
    port map (
      bram_datain => bram_datain_x0,
      ce => ce_x0,
      clk => clk,
      debug_chipscopetrig1 => debug_chipscopetrig1_x0,
      ext_txen => ext_txen_x0,
      plb_abus => plb_abus_x0,
      plb_pavalid => plb_pavalid_x0,
      plb_rnw => plb_rnw_x0,
      plb_wrdbus => plbaddrpref_sgplb_wrdbus_net,
      rssi_anta => rssi_anta_x0,
      rssi_antb => rssi_antb_x0,
      rx_anta_adci => rx_anta_adci_x0,
      rx_anta_adcq => rx_anta_adcq_x0,
      rx_anta_agc_done => rx_anta_agc_done_x0,
      rx_anta_gainbb => rx_anta_gainbb_x0,
      rx_anta_gainrf => rx_anta_gainrf_x0,
      rx_antb_adci => rx_antb_adci_x0,
      rx_antb_adcq => rx_antb_adcq_x0,
      rx_antb_agc_done => rx_antb_agc_done_x0,
      rx_antb_gainbb => rx_antb_gainbb_x0,
      rx_antb_gainrf => rx_antb_gainrf_x0,
      rx_reset => rx_reset_x0,
      sg_plb_addrpref => plbaddrpref_addrpref_net,
      shared_memory_data_out => shared_memory_data_out_x0,
      splb_rst => splb_rst_x0,
      tx_reset => tx_reset_x0,
      tx_starttransmit => tx_starttransmit_x0,
      bram_addr => bram_addr_x0,
      bram_dout => bram_dout_x0,
      bram_reset => bram_reset_x0,
      bram_wen => bram_wen_x0,
      idlefordifs => idlefordifs_x0,
      pktdetect => pktdetect_x0,
      radio_rxen => radio_rxen_x0,
      radio_txen => radio_txen_x0,
      rssi_clk_out => rssi_clk_out_x0,
      rx_debug_antsel => rx_debug_antsel_x0,
      rx_debug_eq_i => rx_debug_eq_i_x0,
      rx_debug_eq_q => rx_debug_eq_q_x0,
      rx_debug_evm => rx_debug_evm_x0,
      rx_debug_payload => rx_debug_payload_x0,
      rx_debug_phasecorrect => rx_debug_phasecorrect_x0,
      rx_debug_phaseerror => rx_debug_phaseerror_x0,
      rx_debug_pktdone => rx_debug_pktdone_x0,
      rx_int_badheader => rx_int_badheader_x0,
      rx_int_badpkt => rx_int_badpkt_x0,
      rx_int_goodheader => rx_int_goodheader_x0,
      rx_int_goodpkt => rx_int_goodpkt_x0,
      rx_pktdetreset => rx_pktdetreset_x0,
      shared_memory_addr => shared_memory_addr_x0,
      shared_memory_ce => shared_memory_ce_x0,
      shared_memory_clk => shared_memory_clk_x0,
      shared_memory_data_in => shared_memory_data_in_x0,
      shared_memory_we => shared_memory_we_x0,
      sl_addrack => sl_addrack_x0,
      sl_rdcomp => sl_rdcomp_x0,
      sl_rddack => sl_rddack_x0,
      sl_rddbus => plbaddrpref_sgsl_rddbus_net,
      sl_wait => sl_wait_x0,
      sl_wrcomp => sl_wrcomp_x0,
      sl_wrdack => sl_wrdack_x0,
      tx_anta_dac_i => tx_anta_dac_i_x0,
      tx_anta_dac_q => tx_anta_dac_q_x0,
      tx_antb_dac_i => tx_antb_dac_i_x0,
      tx_antb_dac_q => tx_antb_dac_q_x0,
      tx_debug_pktrunning => tx_debug_pktrunning_x0,
      tx_pktdone => tx_pktdone_x0
    );

end structural;
